@@ -90,6 +90,16 @@ def fix_relative(html, url):
 
         html = html.replace("src='/", "src='%s/" % base)
         html = html.replace('src="/', 'src="%s/' % base)
+
+
+        html = html.replace("href='//", "href='http://")
+        html = html.replace('href="//', 'href="http://')
+
+
+        html = html.replace("href='/", "href='%s/" % base)
+        html = html.replace('href="/', 'href="%s/' % base)
+
+
     
     except Exception as ex:
         pass    
@@ -143,8 +153,8 @@ def read_feed(source_feed, output=NullOutput()):
             if proxy.address != "X":
             
                 proxies = {
-                  'http': "http://" + proxy.address,
-                  'https': "https://" + proxy.address,
+                  'http': proxy.address,
+                  'https': proxy.address,
                 }
         except:
             pass    
@@ -342,7 +352,7 @@ def read_feed(source_feed, output=NullOutput()):
     output.write("\nUpdating source_feed.interval from %d to %d\n" % (old_interval, source_feed.interval))
     td = datetime.timedelta(minutes=source_feed.interval)
     source_feed.due_poll = timezone.now() + td
-    source_feed.save()
+    source_feed.save(update_fields=["due_poll", "interval", "last_result", "last_modified", "etag", "last_302_start", "last_302_url", "last_success", "live", "status_code", "max_index"])
         
 
 def import_feed(source_feed, feed_body, content_type, output=NullOutput()):
@@ -369,7 +379,7 @@ def import_feed(source_feed, feed_body, content_type, output=NullOutput()):
         for p in posts:
             idx += 1
             p.index = idx
-            p.save()
+            p.save(update_fields=["index"])
             
         source_feed.max_index = idx
     
@@ -398,21 +408,26 @@ def parse_feed_xml(source_feed, feed_content, output):
         source_feed.last_result = "Feed Parse Error"
         entries = []
         ok = False
+        
+    source_feed.save(update_fields=["last_success", "last_result"])
     
     if ok:
         try:
             source_feed.name = f.feed.title
+            source_feed.save(update_fields=["name"])
         except Exception as ex:
             pass
 
         try:
             source_feed.site_url = f.feed.link
+            source_feed.save(update_fields=["site_url"])
         except Exception as ex:
             pass
     
 
         try:
             source_feed.image_url = f.feed.image.href
+            source_feed.save(update_fields=["image_url"])
         except:
             pass
 
@@ -429,6 +444,10 @@ def parse_feed_xml(source_feed, feed_content, output):
         except:
             pass
 
+        try:
+            source_feed.save(update_fields=["description"])
+        except:
+            pass
 
 
         #output.write(entries)
@@ -475,50 +494,59 @@ def parse_feed_xml(source_feed, feed_content, output):
 
             except Exception as ex:
                 output.write("NEW " + guid + "\n")
-                p = Post(index=0, body=" ")
+                p = Post(index=0, body=" ", title="", guid=guid)
                 p.found = timezone.now()
                 changed = True
+
+
+                try:
+                    p.created  = datetime.datetime.fromtimestamp(time.mktime(e.published_parsed)).replace(tzinfo=timezone.utc)
+
+                except Exception as ex2:
+                    output.write("CREATED ERROR")     
+                    p.created  = timezone.now()
+
+
                 p.source = source_feed
+                p.save()
     
             try:
-                title = e.title
+                p.title = e.title
+                p.save(update_fields=["title"])
             except Exception as ex:
-                title = ""
-                        
+                output.write("Title error:" + str(ex))
+                            
             try:
                 p.link = e.link
+                p.save(update_fields=["link"])
             except Exception as ex:
-                p.link = ''
-            p.title = title
+                output.write("Link error:" + str(ex))
 
             try:
                 p.image_url = e.image.href
+                p.save(update_fields=["image_url"])
             except:
                 pass
 
 
-            try:
-                p.created  = datetime.datetime.fromtimestamp(time.mktime(e.published_parsed)).replace(tzinfo=timezone.utc)
-
-            except Exception as ex:
-                output.write("CREATED ERROR")     
-                p.created  = timezone.now()
         
-            p.guid = guid
             try:
                 p.author = e.author
+                p.save(update_fields=["author"])
             except Exception as ex:
                 p.author = ""
 
 
+
             try:
-                p.save()
+                p.body = body                          
+                p.save(update_fields=["body"])
                 # output.write(p.body)
             except Exception as ex:
-                # import pdb; pdb.set_trace()
                 output.write(str(ex))
+                output.write(p.body)                
 
-
+            
             try:
                 seen_files = []
                 for ee in list(p.enclosures.all()):
@@ -570,13 +598,6 @@ def parse_feed_xml(source_feed, feed_content, output):
 
 
 
-            try:
-                p.body = body                          
-                p.save()
-                # output.write(p.body)
-            except Exception as ex:
-                output.write(str(ex))
-                output.write(p.body)
 
     return (ok,changed)
     
@@ -672,6 +693,7 @@ def parse_feed_json(source_feed, feed_content, output):
                 title = ""      
                 
             # borrow the RSS parser's sanitizer
+            
             _customize_sanitizer(parser)
             body  = parser._sanitizeHTML(body, "utf-8", 'text/html') # TODO: validate charset ??
             _customize_sanitizer(parser)
